@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::Config::Author::CSSON;
 
-our $VERSION = '0.0201'; # VERSION
+our $VERSION = '0.0202'; # VERSION
 # ABSTRACT: Dist::Iller config
 
 use Moose;
@@ -68,7 +68,7 @@ has travis => (
     documentation_order => 100,
     documentation_alts => {
         0 => q{Exclude [TravisYML].},
-        1 => q{Include [TravisYML]. By default it tests 5.14+},
+        1 => q{Include [TravisYML].},
     },
 );
 has travis_perl_min => (
@@ -143,20 +143,20 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-47.3%-red.svg" alt="coverage 47.3%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 47.3%](https://img.shields.io/badge/coverage-47.3%-red.svg)
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 42.7%](https://img.shields.io/badge/coverage-42.7%-red.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.0201, released 2016-01-29.
+Version 0.0202, released 2016-02-03.
 
 
 
@@ -190,7 +190,7 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
     <td>&#160;</td>
     <td>&#160;</td>
     <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
-    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
+    <td style="padding-left: 12px;">Include [TravisYML].</td>
 </tr>
 </table>
 
@@ -206,7 +206,7 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
     <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
     <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">read/write</td>
     <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
-    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
+    <td style="padding-left: 12px;">Include [TravisYML].</td>
 </tr>
 </table>
 
